#!C:\ci\gdal_1511390832795\_h_env\python.exe
#******************************************************************************
#  $Id: pct2rgb.py 33127 2016-01-23 19:47:48Z rouault $
#
#  Name:     pct2rgb
#  Project:  GDAL Python Interface
#  Purpose:  Utility to convert paletted images into RGB (or RGBA) images.
#  Author:   Frank Warmerdam, warmerdam@pobox.com
#
#******************************************************************************
#  Copyright (c) 2001, Frank Warmerdam
#  Copyright (c) 2009-2010, Even Rouault <even dot rouault at mines-paris dot org>
#
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#******************************************************************************

import sys

from osgeo import gdal

try:
    progress = gdal.TermProgress_nocb
except:
    progress = gdal.TermProgress

try:
    import numpy as Numeric
    Numeric.arrayrange = Numeric.arange
except ImportError:
    import Numeric


def Usage():
    print('Usage: pct2rgb.py [-of format] [-b <band>] [-rgba] source_file dest_file')
    sys.exit(1)

# =============================================================================
# 	Mainline
# =============================================================================

format = 'GTiff'
src_filename = None
dst_filename = None
out_bands = 3
band_number = 1

gdal.AllRegister()
argv = gdal.GeneralCmdLineProcessor( sys.argv )
if argv is None:
    sys.exit( 0 )

# Parse command line arguments.
i = 1
while i < len(argv):
    arg = argv[i]

    if arg == '-of':
        i = i + 1
        format = argv[i]

    elif arg == '-b':
        i = i + 1
        band_number = int(argv[i])

    elif arg == '-rgba':
        out_bands = 4

    elif src_filename is None:
        src_filename = argv[i]

    elif dst_filename is None:
        dst_filename = argv[i]

    else:
        Usage()

    i = i + 1

if dst_filename is None:
    Usage()

# ----------------------------------------------------------------------------
# Open source file

src_ds = gdal.Open( src_filename )
if src_ds is None:
    print('Unable to open %s ' % src_filename)
    sys.exit(1)

src_band = src_ds.GetRasterBand(band_number)

# ----------------------------------------------------------------------------
# Ensure we recognise the driver.

dst_driver = gdal.GetDriverByName(format)
if dst_driver is None:
    print('"%s" driver not registered.' % format)
    sys.exit(1)

# ----------------------------------------------------------------------------
# Build color table.

ct = src_band.GetRasterColorTable()

ct_size = ct.GetCount()
lookup = [Numeric.arrayrange(ct_size),
          Numeric.arrayrange(ct_size),
          Numeric.arrayrange(ct_size),
          Numeric.ones(ct_size) * 255]

if ct is not None:
    for i in range(ct_size):
        entry = ct.GetColorEntry(i)
        for c in range(4):
            lookup[c][i] = entry[c]

# ----------------------------------------------------------------------------
# Create the working file.

if format == 'GTiff':
    tif_filename = dst_filename
else:
    tif_filename = 'temp.tif'

gtiff_driver = gdal.GetDriverByName( 'GTiff' )

tif_ds = gtiff_driver.Create( tif_filename,
                              src_ds.RasterXSize, src_ds.RasterYSize, out_bands )


# ----------------------------------------------------------------------------
# We should copy projection information and so forth at this point.

tif_ds.SetProjection( src_ds.GetProjection() )
tif_ds.SetGeoTransform( src_ds.GetGeoTransform() )
if src_ds.GetGCPCount() > 0:
    tif_ds.SetGCPs( src_ds.GetGCPs(), src_ds.GetGCPProjection() )

# ----------------------------------------------------------------------------
# Do the processing one scanline at a time.

progress( 0.0 )
for iY in range(src_ds.RasterYSize):
    src_data = src_band.ReadAsArray(0,iY,src_ds.RasterXSize,1)

    for iBand in range(out_bands):
        band_lookup = lookup[iBand]

        dst_data = Numeric.take(band_lookup,src_data)
        tif_ds.GetRasterBand(iBand+1).WriteArray(dst_data,0,iY)

    progress( (iY+1.0) / src_ds.RasterYSize )


tif_ds = None

# ----------------------------------------------------------------------------
# Translate intermediate file to output format if desired format is not TIFF.

if tif_filename != dst_filename:
    tif_ds = gdal.Open( tif_filename )
    dst_driver.CreateCopy( dst_filename, tif_ds )
    tif_ds = None

    gtiff_driver.Delete( tif_filename )



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_osr', [dirname(__file__)])
        except ImportError:
            import _osr
            return _osr
        if fp is not None:
            try:
                _mod = imp.load_module('_osr', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _osr = swig_import_helper()
    del swig_import_helper
else:
    import _osr
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0



_osr.SRS_WKT_WGS84_swigconstant(_osr)
SRS_WKT_WGS84 = _osr.SRS_WKT_WGS84

_osr.SRS_PT_ALBERS_CONIC_EQUAL_AREA_swigconstant(_osr)
SRS_PT_ALBERS_CONIC_EQUAL_AREA = _osr.SRS_PT_ALBERS_CONIC_EQUAL_AREA

_osr.SRS_PT_AZIMUTHAL_EQUIDISTANT_swigconstant(_osr)
SRS_PT_AZIMUTHAL_EQUIDISTANT = _osr.SRS_PT_AZIMUTHAL_EQUIDISTANT

_osr.SRS_PT_CASSINI_SOLDNER_swigconstant(_osr)
SRS_PT_CASSINI_SOLDNER = _osr.SRS_PT_CASSINI_SOLDNER

_osr.SRS_PT_CYLINDRICAL_EQUAL_AREA_swigconstant(_osr)
SRS_PT_CYLINDRICAL_EQUAL_AREA = _osr.SRS_PT_CYLINDRICAL_EQUAL_AREA

_osr.SRS_PT_BONNE_swigconstant(_osr)
SRS_PT_BONNE = _osr.SRS_PT_BONNE

_osr.SRS_PT_ECKERT_I_swigconstant(_osr)
SRS_PT_ECKERT_I = _osr.SRS_PT_ECKERT_I

_osr.SRS_PT_ECKERT_II_swigconstant(_osr)
SRS_PT_ECKERT_II = _osr.SRS_PT_ECKERT_II

_osr.SRS_PT_ECKERT_III_swigconstant(_osr)
SRS_PT_ECKERT_III = _osr.SRS_PT_ECKERT_III

_osr.SRS_PT_ECKERT_IV_swigconstant(_osr)
SRS_PT_ECKERT_IV = _osr.SRS_PT_ECKERT_IV

_osr.SRS_PT_ECKERT_V_swigconstant(_osr)
SRS_PT_ECKERT_V = _osr.SRS_PT_ECKERT_V

_osr.SRS_PT_ECKERT_VI_swigconstant(_osr)
SRS_PT_ECKERT_VI = _osr.SRS_PT_ECKERT_VI

_osr.SRS_PT_EQUIDISTANT_CONIC_swigconstant(_osr)
SRS_PT_EQUIDISTANT_CONIC = _osr.SRS_PT_EQUIDISTANT_CONIC

_osr.SRS_PT_EQUIRECTANGULAR_swigconstant(_osr)
SRS_PT_EQUIRECTANGULAR = _osr.SRS_PT_EQUIRECTANGULAR

_osr.SRS_PT_GALL_STEREOGRAPHIC_swigconstant(_osr)
SRS_PT_GALL_STEREOGRAPHIC = _osr.SRS_PT_GALL_STEREOGRAPHIC

_osr.SRS_PT_GAUSSSCHREIBERTMERCATOR_swigconstant(_osr)
SRS_PT_GAUSSSCHREIBERTMERCATOR = _osr.SRS_PT_GAUSSSCHREIBERTMERCATOR

_osr.SRS_PT_GEOSTATIONARY_SATELLITE_swigconstant(_osr)
SRS_PT_GEOSTATIONARY_SATELLITE = _osr.SRS_PT_GEOSTATIONARY_SATELLITE

_osr.SRS_PT_GOODE_HOMOLOSINE_swigconstant(_osr)
SRS_PT_GOODE_HOMOLOSINE = _osr.SRS_PT_GOODE_HOMOLOSINE

_osr.SRS_PT_IGH_swigconstant(_osr)
SRS_PT_IGH = _osr.SRS_PT_IGH

_osr.SRS_PT_GNOMONIC_swigconstant(_osr)
SRS_PT_GNOMONIC = _osr.SRS_PT_GNOMONIC

_osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR_AZIMUTH_CENTER_swigconstant(_osr)
SRS_PT_HOTINE_OBLIQUE_MERCATOR_AZIMUTH_CENTER = _osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR_AZIMUTH_CENTER

_osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR_swigconstant(_osr)
SRS_PT_HOTINE_OBLIQUE_MERCATOR = _osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR

_osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR_TWO_POINT_NATURAL_ORIGIN_swigconstant(_osr)
SRS_PT_HOTINE_OBLIQUE_MERCATOR_TWO_POINT_NATURAL_ORIGIN = _osr.SRS_PT_HOTINE_OBLIQUE_MERCATOR_TWO_POINT_NATURAL_ORIGIN

_osr.SRS_PT_LABORDE_OBLIQUE_MERCATOR_swigconstant(_osr)
SRS_PT_LABORDE_OBLIQUE_MERCATOR = _osr.SRS_PT_LABORDE_OBLIQUE_MERCATOR

_osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_1SP_swigconstant(_osr)
SRS_PT_LAMBERT_CONFORMAL_CONIC_1SP = _osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_1SP

_osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP_swigconstant(_osr)
SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP = _osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP

_osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP_BELGIUM_swigconstant(_osr)
SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP_BELGIUM = _osr.SRS_PT_LAMBERT_CONFORMAL_CONIC_2SP_BELGIUM

_osr.SRS_PT_LAMBERT_AZIMUTHAL_EQUAL_AREA_swigconstant(_osr)
SRS_PT_LAMBERT_AZIMUTHAL_EQUAL_AREA = _osr.SRS_PT_LAMBERT_AZIMUTHAL_EQUAL_AREA

_osr.SRS_PT_MERCATOR_1SP_swigconstant(_osr)
SRS_PT_MERCATOR_1SP = _osr.SRS_PT_MERCATOR_1SP

_osr.SRS_PT_MERCATOR_2SP_swigconstant(_osr)
SRS_PT_MERCATOR_2SP = _osr.SRS_PT_MERCATOR_2SP

_osr.SRS_PT_MERCATOR_AUXILIARY_SPHERE_swigconstant(_osr)
SRS_PT_MERCATOR_AUXILIARY_SPHERE = _osr.SRS_PT_MERCATOR_AUXILIARY_SPHERE

_osr.SRS_PT_MILLER_CYLINDRICAL_swigconstant(_osr)
SRS_PT_MILLER_CYLINDRICAL = _osr.SRS_PT_MILLER_CYLINDRICAL

_osr.SRS_PT_MOLLWEIDE_swigconstant(_osr)
SRS_PT_MOLLWEIDE = _osr.SRS_PT_MOLLWEIDE

_osr.SRS_PT_NEW_ZEALAND_MAP_GRID_swigconstant(_osr)
SRS_PT_NEW_ZEALAND_MAP_GRID = _osr.SRS_PT_NEW_ZEALAND_MAP_GRID

_osr.SRS_PT_OBLIQUE_STEREOGRAPHIC_swigconstant(_osr)
SRS_PT_OBLIQUE_STEREOGRAPHIC = _osr.SRS_PT_OBLIQUE_STEREOGRAPHIC

_osr.SRS_PT_ORTHOGRAPHIC_swigconstant(_osr)
SRS_PT_ORTHOGRAPHIC = _osr.SRS_PT_ORTHOGRAPHIC

_osr.SRS_PT_POLAR_STEREOGRAPHIC_swigconstant(_osr)
SRS_PT_POLAR_STEREOGRAPHIC = _osr.SRS_PT_POLAR_STEREOGRAPHIC

_osr.SRS_PT_POLYCONIC_swigconstant(_osr)
SRS_PT_POLYCONIC = _osr.SRS_PT_POLYCONIC

_osr.SRS_PT_ROBINSON_swigconstant(_osr)
SRS_PT_ROBINSON = _osr.SRS_PT_ROBINSON

_osr.SRS_PT_SINUSOIDAL_swigconstant(_osr)
SRS_PT_SINUSOIDAL = _osr.SRS_PT_SINUSOIDAL

_osr.SRS_PT_STEREOGRAPHIC_swigconstant(_osr)
SRS_PT_STEREOGRAPHIC = _osr.SRS_PT_STEREOGRAPHIC

_osr.SRS_PT_SWISS_OBLIQUE_CYLINDRICAL_swigconstant(_osr)
SRS_PT_SWISS_OBLIQUE_CYLINDRICAL = _osr.SRS_PT_SWISS_OBLIQUE_CYLINDRICAL

_osr.SRS_PT_TRANSVERSE_MERCATOR_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR = _osr.SRS_PT_TRANSVERSE_MERCATOR

_osr.SRS_PT_TRANSVERSE_MERCATOR_SOUTH_ORIENTED_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_SOUTH_ORIENTED = _osr.SRS_PT_TRANSVERSE_MERCATOR_SOUTH_ORIENTED

_osr.SRS_PT_TRANSVERSE_MERCATOR_MI_21_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_MI_21 = _osr.SRS_PT_TRANSVERSE_MERCATOR_MI_21

_osr.SRS_PT_TRANSVERSE_MERCATOR_MI_22_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_MI_22 = _osr.SRS_PT_TRANSVERSE_MERCATOR_MI_22

_osr.SRS_PT_TRANSVERSE_MERCATOR_MI_23_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_MI_23 = _osr.SRS_PT_TRANSVERSE_MERCATOR_MI_23

_osr.SRS_PT_TRANSVERSE_MERCATOR_MI_24_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_MI_24 = _osr.SRS_PT_TRANSVERSE_MERCATOR_MI_24

_osr.SRS_PT_TRANSVERSE_MERCATOR_MI_25_swigconstant(_osr)
SRS_PT_TRANSVERSE_MERCATOR_MI_25 = _osr.SRS_PT_TRANSVERSE_MERCATOR_MI_25

_osr.SRS_PT_TUNISIA_MINING_GRID_swigconstant(_osr)
SRS_PT_TUNISIA_MINING_GRID = _osr.SRS_PT_TUNISIA_MINING_GRID

_osr.SRS_PT_TWO_POINT_EQUIDISTANT_swigconstant(_osr)
SRS_PT_TWO_POINT_EQUIDISTANT = _osr.SRS_PT_TWO_POINT_EQUIDISTANT

_osr.SRS_PT_VANDERGRINTEN_swigconstant(_osr)
SRS_PT_VANDERGRINTEN = _osr.SRS_PT_VANDERGRINTEN

_osr.SRS_PT_KROVAK_swigconstant(_osr)
SRS_PT_KROVAK = _osr.SRS_PT_KROVAK

_osr.SRS_PT_IMW_POLYCONIC_swigconstant(_osr)
SRS_PT_IMW_POLYCONIC = _osr.SRS_PT_IMW_POLYCONIC

_osr.SRS_PT_WAGNER_I_swigconstant(_osr)
SRS_PT_WAGNER_I = _osr.SRS_PT_WAGNER_I

_osr.SRS_PT_WAGNER_II_swigconstant(_osr)
SRS_PT_WAGNER_II = _osr.SRS_PT_WAGNER_II

_osr.SRS_PT_WAGNER_III_swigconstant(_osr)
SRS_PT_WAGNER_III = _osr.SRS_PT_WAGNER_III

_osr.SRS_PT_WAGNER_IV_swigconstant(_osr)
SRS_PT_WAGNER_IV = _osr.SRS_PT_WAGNER_IV

_osr.SRS_PT_WAGNER_V_swigconstant(_osr)
SRS_PT_WAGNER_V = _osr.SRS_PT_WAGNER_V

_osr.SRS_PT_WAGNER_VI_swigconstant(_osr)
SRS_PT_WAGNER_VI = _osr.SRS_PT_WAGNER_VI

_osr.SRS_PT_WAGNER_VII_swigconstant(_osr)
SRS_PT_WAGNER_VII = _osr.SRS_PT_WAGNER_VII

_osr.SRS_PT_QSC_swigconstant(_osr)
SRS_PT_QSC = _osr.SRS_PT_QSC

_osr.SRS_PT_AITOFF_swigconstant(_osr)
SRS_PT_AITOFF = _osr.SRS_PT_AITOFF

_osr.SRS_PT_WINKEL_I_swigconstant(_osr)
SRS_PT_WINKEL_I = _osr.SRS_PT_WINKEL_I

_osr.SRS_PT_WINKEL_II_swigconstant(_osr)
SRS_PT_WINKEL_II = _osr.SRS_PT_WINKEL_II

_osr.SRS_PT_WINKEL_TRIPEL_swigconstant(_osr)
SRS_PT_WINKEL_TRIPEL = _osr.SRS_PT_WINKEL_TRIPEL

_osr.SRS_PT_CRASTER_PARABOLIC_swigconstant(_osr)
SRS_PT_CRASTER_PARABOLIC = _osr.SRS_PT_CRASTER_PARABOLIC

_osr.SRS_PT_LOXIMUTHAL_swigconstant(_osr)
SRS_PT_LOXIMUTHAL = _osr.SRS_PT_LOXIMUTHAL

_osr.SRS_PT_QUARTIC_AUTHALIC_swigconstant(_osr)
SRS_PT_QUARTIC_AUTHALIC = _osr.SRS_PT_QUARTIC_AUTHALIC

_osr.SRS_PT_SCH_swigconstant(_osr)
SRS_PT_SCH = _osr.SRS_PT_SCH

_osr.SRS_PP_CENTRAL_MERIDIAN_swigconstant(_osr)
SRS_PP_CENTRAL_MERIDIAN = _osr.SRS_PP_CENTRAL_MERIDIAN

_osr.SRS_PP_SCALE_FACTOR_swigconstant(_osr)
SRS_PP_SCALE_FACTOR = _osr.SRS_PP_SCALE_FACTOR

_osr.SRS_PP_STANDARD_PARALLEL_1_swigconstant(_osr)
SRS_PP_STANDARD_PARALLEL_1 = _osr.SRS_PP_STANDARD_PARALLEL_1

_osr.SRS_PP_STANDARD_PARALLEL_2_swigconstant(_osr)
SRS_PP_STANDARD_PARALLEL_2 = _osr.SRS_PP_STANDARD_PARALLEL_2

_osr.SRS_PP_PSEUDO_STD_PARALLEL_1_swigconstant(_osr)
SRS_PP_PSEUDO_STD_PARALLEL_1 = _osr.SRS_PP_PSEUDO_STD_PARALLEL_1

_osr.SRS_PP_LONGITUDE_OF_CENTER_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_CENTER = _osr.SRS_PP_LONGITUDE_OF_CENTER

_osr.SRS_PP_LATITUDE_OF_CENTER_swigconstant(_osr)
SRS_PP_LATITUDE_OF_CENTER = _osr.SRS_PP_LATITUDE_OF_CENTER

_osr.SRS_PP_LONGITUDE_OF_ORIGIN_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_ORIGIN = _osr.SRS_PP_LONGITUDE_OF_ORIGIN

_osr.SRS_PP_LATITUDE_OF_ORIGIN_swigconstant(_osr)
SRS_PP_LATITUDE_OF_ORIGIN = _osr.SRS_PP_LATITUDE_OF_ORIGIN

_osr.SRS_PP_FALSE_EASTING_swigconstant(_osr)
SRS_PP_FALSE_EASTING = _osr.SRS_PP_FALSE_EASTING

_osr.SRS_PP_FALSE_NORTHING_swigconstant(_osr)
SRS_PP_FALSE_NORTHING = _osr.SRS_PP_FALSE_NORTHING

_osr.SRS_PP_AZIMUTH_swigconstant(_osr)
SRS_PP_AZIMUTH = _osr.SRS_PP_AZIMUTH

_osr.SRS_PP_LONGITUDE_OF_POINT_1_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_POINT_1 = _osr.SRS_PP_LONGITUDE_OF_POINT_1

_osr.SRS_PP_LATITUDE_OF_POINT_1_swigconstant(_osr)
SRS_PP_LATITUDE_OF_POINT_1 = _osr.SRS_PP_LATITUDE_OF_POINT_1

_osr.SRS_PP_LONGITUDE_OF_POINT_2_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_POINT_2 = _osr.SRS_PP_LONGITUDE_OF_POINT_2

_osr.SRS_PP_LATITUDE_OF_POINT_2_swigconstant(_osr)
SRS_PP_LATITUDE_OF_POINT_2 = _osr.SRS_PP_LATITUDE_OF_POINT_2

_osr.SRS_PP_LONGITUDE_OF_POINT_3_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_POINT_3 = _osr.SRS_PP_LONGITUDE_OF_POINT_3

_osr.SRS_PP_LATITUDE_OF_POINT_3_swigconstant(_osr)
SRS_PP_LATITUDE_OF_POINT_3 = _osr.SRS_PP_LATITUDE_OF_POINT_3

_osr.SRS_PP_RECTIFIED_GRID_ANGLE_swigconstant(_osr)
SRS_PP_RECTIFIED_GRID_ANGLE = _osr.SRS_PP_RECTIFIED_GRID_ANGLE

_osr.SRS_PP_LANDSAT_NUMBER_swigconstant(_osr)
SRS_PP_LANDSAT_NUMBER = _osr.SRS_PP_LANDSAT_NUMBER

_osr.SRS_PP_PATH_NUMBER_swigconstant(_osr)
SRS_PP_PATH_NUMBER = _osr.SRS_PP_PATH_NUMBER

_osr.SRS_PP_PERSPECTIVE_POINT_HEIGHT_swigconstant(_osr)
SRS_PP_PERSPECTIVE_POINT_HEIGHT = _osr.SRS_PP_PERSPECTIVE_POINT_HEIGHT

_osr.SRS_PP_SATELLITE_HEIGHT_swigconstant(_osr)
SRS_PP_SATELLITE_HEIGHT = _osr.SRS_PP_SATELLITE_HEIGHT

_osr.SRS_PP_FIPSZONE_swigconstant(_osr)
SRS_PP_FIPSZONE = _osr.SRS_PP_FIPSZONE

_osr.SRS_PP_ZONE_swigconstant(_osr)
SRS_PP_ZONE = _osr.SRS_PP_ZONE

_osr.SRS_PP_LATITUDE_OF_1ST_POINT_swigconstant(_osr)
SRS_PP_LATITUDE_OF_1ST_POINT = _osr.SRS_PP_LATITUDE_OF_1ST_POINT

_osr.SRS_PP_LONGITUDE_OF_1ST_POINT_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_1ST_POINT = _osr.SRS_PP_LONGITUDE_OF_1ST_POINT

_osr.SRS_PP_LATITUDE_OF_2ND_POINT_swigconstant(_osr)
SRS_PP_LATITUDE_OF_2ND_POINT = _osr.SRS_PP_LATITUDE_OF_2ND_POINT

_osr.SRS_PP_LONGITUDE_OF_2ND_POINT_swigconstant(_osr)
SRS_PP_LONGITUDE_OF_2ND_POINT = _osr.SRS_PP_LONGITUDE_OF_2ND_POINT

_osr.SRS_PP_PEG_POINT_LATITUDE_swigconstant(_osr)
SRS_PP_PEG_POINT_LATITUDE = _osr.SRS_PP_PEG_POINT_LATITUDE

_osr.SRS_PP_PEG_POINT_LONGITUDE_swigconstant(_osr)
SRS_PP_PEG_POINT_LONGITUDE = _osr.SRS_PP_PEG_POINT_LONGITUDE

_osr.SRS_PP_PEG_POINT_HEADING_swigconstant(_osr)
SRS_PP_PEG_POINT_HEADING = _osr.SRS_PP_PEG_POINT_HEADING

_osr.SRS_PP_PEG_POINT_HEIGHT_swigconstant(_osr)
SRS_PP_PEG_POINT_HEIGHT = _osr.SRS_PP_PEG_POINT_HEIGHT

_osr.SRS_UL_METER_swigconstant(_osr)
SRS_UL_METER = _osr.SRS_UL_METER

_osr.SRS_UL_FOOT_swigconstant(_osr)
SRS_UL_FOOT = _osr.SRS_UL_FOOT

_osr.SRS_UL_FOOT_CONV_swigconstant(_osr)
SRS_UL_FOOT_CONV = _osr.SRS_UL_FOOT_CONV

_osr.SRS_UL_US_FOOT_swigconstant(_osr)
SRS_UL_US_FOOT = _osr.SRS_UL_US_FOOT

_osr.SRS_UL_US_FOOT_CONV_swigconstant(_osr)
SRS_UL_US_FOOT_CONV = _osr.SRS_UL_US_FOOT_CONV

_osr.SRS_UL_NAUTICAL_MILE_swigconstant(_osr)
SRS_UL_NAUTICAL_MILE = _osr.SRS_UL_NAUTICAL_MILE

_osr.SRS_UL_NAUTICAL_MILE_CONV_swigconstant(_osr)
SRS_UL_NAUTICAL_MILE_CONV = _osr.SRS_UL_NAUTICAL_MILE_CONV

_osr.SRS_UL_LINK_swigconstant(_osr)
SRS_UL_LINK = _osr.SRS_UL_LINK

_osr.SRS_UL_LINK_CONV_swigconstant(_osr)
SRS_UL_LINK_CONV = _osr.SRS_UL_LINK_CONV

_osr.SRS_UL_CHAIN_swigconstant(_osr)
SRS_UL_CHAIN = _osr.SRS_UL_CHAIN

_osr.SRS_UL_CHAIN_CONV_swigconstant(_osr)
SRS_UL_CHAIN_CONV = _osr.SRS_UL_CHAIN_CONV

_osr.SRS_UL_ROD_swigconstant(_osr)
SRS_UL_ROD = _osr.SRS_UL_ROD

_osr.SRS_UL_ROD_CONV_swigconstant(_osr)
SRS_UL_ROD_CONV = _osr.SRS_UL_ROD_CONV

_osr.SRS_UL_LINK_Clarke_swigconstant(_osr)
SRS_UL_LINK_Clarke = _osr.SRS_UL_LINK_Clarke

_osr.SRS_UL_LINK_Clarke_CONV_swigconstant(_osr)
SRS_UL_LINK_Clarke_CONV = _osr.SRS_UL_LINK_Clarke_CONV

_osr.SRS_UL_KILOMETER_swigconstant(_osr)
SRS_UL_KILOMETER = _osr.SRS_UL_KILOMETER

_osr.SRS_UL_KILOMETER_CONV_swigconstant(_osr)
SRS_UL_KILOMETER_CONV = _osr.SRS_UL_KILOMETER_CONV

_osr.SRS_UL_DECIMETER_swigconstant(_osr)
SRS_UL_DECIMETER = _osr.SRS_UL_DECIMETER

_osr.SRS_UL_DECIMETER_CONV_swigconstant(_osr)
SRS_UL_DECIMETER_CONV = _osr.SRS_UL_DECIMETER_CONV

_osr.SRS_UL_CENTIMETER_swigconstant(_osr)
SRS_UL_CENTIMETER = _osr.SRS_UL_CENTIMETER

_osr.SRS_UL_CENTIMETER_CONV_swigconstant(_osr)
SRS_UL_CENTIMETER_CONV = _osr.SRS_UL_CENTIMETER_CONV

_osr.SRS_UL_MILLIMETER_swigconstant(_osr)
SRS_UL_MILLIMETER = _osr.SRS_UL_MILLIMETER

_osr.SRS_UL_MILLIMETER_CONV_swigconstant(_osr)
SRS_UL_MILLIMETER_CONV = _osr.SRS_UL_MILLIMETER_CONV

_osr.SRS_UL_INTL_NAUT_MILE_swigconstant(_osr)
SRS_UL_INTL_NAUT_MILE = _osr.SRS_UL_INTL_NAUT_MILE

_osr.SRS_UL_INTL_NAUT_MILE_CONV_swigconstant(_osr)
SRS_UL_INTL_NAUT_MILE_CONV = _osr.SRS_UL_INTL_NAUT_MILE_CONV

_osr.SRS_UL_INTL_INCH_swigconstant(_osr)
SRS_UL_INTL_INCH = _osr.SRS_UL_INTL_INCH

_osr.SRS_UL_INTL_INCH_CONV_swigconstant(_osr)
SRS_UL_INTL_INCH_CONV = _osr.SRS_UL_INTL_INCH_CONV

_osr.SRS_UL_INTL_FOOT_swigconstant(_osr)
SRS_UL_INTL_FOOT = _osr.SRS_UL_INTL_FOOT

_osr.SRS_UL_INTL_FOOT_CONV_swigconstant(_osr)
SRS_UL_INTL_FOOT_CONV = _osr.SRS_UL_INTL_FOOT_CONV

_osr.SRS_UL_INTL_YARD_swigconstant(_osr)
SRS_UL_INTL_YARD = _osr.SRS_UL_INTL_YARD

_osr.SRS_UL_INTL_YARD_CONV_swigconstant(_osr)
SRS_UL_INTL_YARD_CONV = _osr.SRS_UL_INTL_YARD_CONV

_osr.SRS_UL_INTL_STAT_MILE_swigconstant(_osr)
SRS_UL_INTL_STAT_MILE = _osr.SRS_UL_INTL_STAT_MILE

_osr.SRS_UL_INTL_STAT_MILE_CONV_swigconstant(_osr)
SRS_UL_INTL_STAT_MILE_CONV = _osr.SRS_UL_INTL_STAT_MILE_CONV

_osr.SRS_UL_INTL_FATHOM_swigconstant(_osr)
SRS_UL_INTL_FATHOM = _osr.SRS_UL_INTL_FATHOM

_osr.SRS_UL_INTL_FATHOM_CONV_swigconstant(_osr)
SRS_UL_INTL_FATHOM_CONV = _osr.SRS_UL_INTL_FATHOM_CONV

_osr.SRS_UL_INTL_CHAIN_swigconstant(_osr)
SRS_UL_INTL_CHAIN = _osr.SRS_UL_INTL_CHAIN

_osr.SRS_UL_INTL_CHAIN_CONV_swigconstant(_osr)
SRS_UL_INTL_CHAIN_CONV = _osr.SRS_UL_INTL_CHAIN_CONV

_osr.SRS_UL_INTL_LINK_swigconstant(_osr)
SRS_UL_INTL_LINK = _osr.SRS_UL_INTL_LINK

_osr.SRS_UL_INTL_LINK_CONV_swigconstant(_osr)
SRS_UL_INTL_LINK_CONV = _osr.SRS_UL_INTL_LINK_CONV

_osr.SRS_UL_US_INCH_swigconstant(_osr)
SRS_UL_US_INCH = _osr.SRS_UL_US_INCH

_osr.SRS_UL_US_INCH_CONV_swigconstant(_osr)
SRS_UL_US_INCH_CONV = _osr.SRS_UL_US_INCH_CONV

_osr.SRS_UL_US_YARD_swigconstant(_osr)
SRS_UL_US_YARD = _osr.SRS_UL_US_YARD

_osr.SRS_UL_US_YARD_CONV_swigconstant(_osr)
SRS_UL_US_YARD_CONV = _osr.SRS_UL_US_YARD_CONV

_osr.SRS_UL_US_CHAIN_swigconstant(_osr)
SRS_UL_US_CHAIN = _osr.SRS_UL_US_CHAIN

_osr.SRS_UL_US_CHAIN_CONV_swigconstant(_osr)
SRS_UL_US_CHAIN_CONV = _osr.SRS_UL_US_CHAIN_CONV

_osr.SRS_UL_US_STAT_MILE_swigconstant(_osr)
SRS_UL_US_STAT_MILE = _osr.SRS_UL_US_STAT_MILE

_osr.SRS_UL_US_STAT_MILE_CONV_swigconstant(_osr)
SRS_UL_US_STAT_MILE_CONV = _osr.SRS_UL_US_STAT_MILE_CONV

_osr.SRS_UL_INDIAN_YARD_swigconstant(_osr)
SRS_UL_INDIAN_YARD = _osr.SRS_UL_INDIAN_YARD

_osr.SRS_UL_INDIAN_YARD_CONV_swigconstant(_osr)
SRS_UL_INDIAN_YARD_CONV = _osr.SRS_UL_INDIAN_YARD_CONV

_osr.SRS_UL_INDIAN_FOOT_swigconstant(_osr)
SRS_UL_INDIAN_FOOT = _osr.SRS_UL_INDIAN_FOOT

_osr.SRS_UL_INDIAN_FOOT_CONV_swigconstant(_osr)
SRS_UL_INDIAN_FOOT_CONV = _osr.SRS_UL_INDIAN_FOOT_CONV

_osr.SRS_UL_INDIAN_CHAIN_swigconstant(_osr)
SRS_UL_INDIAN_CHAIN = _osr.SRS_UL_INDIAN_CHAIN

_osr.SRS_UL_INDIAN_CHAIN_CONV_swigconstant(_osr)
SRS_UL_INDIAN_CHAIN_CONV = _osr.SRS_UL_INDIAN_CHAIN_CONV

_osr.SRS_UA_DEGREE_swigconstant(_osr)
SRS_UA_DEGREE = _osr.SRS_UA_DEGREE

_osr.SRS_UA_DEGREE_CONV_swigconstant(_osr)
SRS_UA_DEGREE_CONV = _osr.SRS_UA_DEGREE_CONV

_osr.SRS_UA_RADIAN_swigconstant(_osr)
SRS_UA_RADIAN = _osr.SRS_UA_RADIAN

_osr.SRS_PM_GREENWICH_swigconstant(_osr)
SRS_PM_GREENWICH = _osr.SRS_PM_GREENWICH

_osr.SRS_DN_NAD27_swigconstant(_osr)
SRS_DN_NAD27 = _osr.SRS_DN_NAD27

_osr.SRS_DN_NAD83_swigconstant(_osr)
SRS_DN_NAD83 = _osr.SRS_DN_NAD83

_osr.SRS_DN_WGS72_swigconstant(_osr)
SRS_DN_WGS72 = _osr.SRS_DN_WGS72

_osr.SRS_DN_WGS84_swigconstant(_osr)
SRS_DN_WGS84 = _osr.SRS_DN_WGS84

_osr.SRS_WGS84_SEMIMAJOR_swigconstant(_osr)
SRS_WGS84_SEMIMAJOR = _osr.SRS_WGS84_SEMIMAJOR

_osr.SRS_WGS84_INVFLATTENING_swigconstant(_osr)
SRS_WGS84_INVFLATTENING = _osr.SRS_WGS84_INVFLATTENING

_osr.OAO_Other_swigconstant(_osr)
OAO_Other = _osr.OAO_Other

_osr.OAO_North_swigconstant(_osr)
OAO_North = _osr.OAO_North

_osr.OAO_South_swigconstant(_osr)
OAO_South = _osr.OAO_South

_osr.OAO_East_swigconstant(_osr)
OAO_East = _osr.OAO_East

_osr.OAO_West_swigconstant(_osr)
OAO_West = _osr.OAO_West

_osr.OAO_Up_swigconstant(_osr)
OAO_Up = _osr.OAO_Up

_osr.OAO_Down_swigconstant(_osr)
OAO_Down = _osr.OAO_Down

def GetUseExceptions(*args):
    """GetUseExceptions() -> int"""
    return _osr.GetUseExceptions(*args)

def UseExceptions(*args):
    """UseExceptions()"""
    return _osr.UseExceptions(*args)

def DontUseExceptions(*args):
    """DontUseExceptions()"""
    return _osr.DontUseExceptions(*args)

def GetWellKnownGeogCSAsWKT(*args):
    """GetWellKnownGeogCSAsWKT(char const * name) -> OGRErr"""
    return _osr.GetWellKnownGeogCSAsWKT(*args)

def GetUserInputAsWKT(*args):
    """GetUserInputAsWKT(char const * name) -> OGRErr"""
    return _osr.GetUserInputAsWKT(*args)
class SpatialReference(_object):
    """Proxy of C++ OSRSpatialReferenceShadow class."""

    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SpatialReference, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SpatialReference, name)
    __repr__ = _swig_repr

    def __init__(self, *args, **kwargs):
        """__init__(OSRSpatialReferenceShadow self, char const * wkt) -> SpatialReference"""
        this = _osr.new_SpatialReference(*args, **kwargs)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _osr.delete_SpatialReference
    __del__ = lambda self: None

    def __str__(self, *args):
        """__str__(SpatialReference self) -> retStringAndCPLFree *"""
        return _osr.SpatialReference___str__(self, *args)


    def IsSame(self, *args):
        """IsSame(SpatialReference self, SpatialReference rhs) -> int"""
        return _osr.SpatialReference_IsSame(self, *args)


    def IsSameGeogCS(self, *args):
        """IsSameGeogCS(SpatialReference self, SpatialReference rhs) -> int"""
        return _osr.SpatialReference_IsSameGeogCS(self, *args)


    def IsSameVertCS(self, *args):
        """IsSameVertCS(SpatialReference self, SpatialReference rhs) -> int"""
        return _osr.SpatialReference_IsSameVertCS(self, *args)


    def IsGeographic(self, *args):
        """IsGeographic(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsGeographic(self, *args)


    def IsProjected(self, *args):
        """IsProjected(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsProjected(self, *args)


    def IsCompound(self, *args):
        """IsCompound(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsCompound(self, *args)


    def IsGeocentric(self, *args):
        """IsGeocentric(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsGeocentric(self, *args)


    def IsLocal(self, *args):
        """IsLocal(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsLocal(self, *args)


    def IsVertical(self, *args):
        """IsVertical(SpatialReference self) -> int"""
        return _osr.SpatialReference_IsVertical(self, *args)


    def EPSGTreatsAsLatLong(self, *args):
        """EPSGTreatsAsLatLong(SpatialReference self) -> int"""
        return _osr.SpatialReference_EPSGTreatsAsLatLong(self, *args)


    def EPSGTreatsAsNorthingEasting(self, *args):
        """EPSGTreatsAsNorthingEasting(SpatialReference self) -> int"""
        return _osr.SpatialReference_EPSGTreatsAsNorthingEasting(self, *args)


    def SetAuthority(self, *args):
        """SetAuthority(SpatialReference self, char const * pszTargetKey, char const * pszAuthority, int nCode) -> OGRErr"""
        return _osr.SpatialReference_SetAuthority(self, *args)


    def GetAttrValue(self, *args):
        """GetAttrValue(SpatialReference self, char const * name, int child=0) -> char const *"""
        return _osr.SpatialReference_GetAttrValue(self, *args)


    def SetAttrValue(self, *args):
        """SetAttrValue(SpatialReference self, char const * name, char const * value) -> OGRErr"""
        return _osr.SpatialReference_SetAttrValue(self, *args)


    def SetAngularUnits(self, *args):
        """SetAngularUnits(SpatialReference self, char const * name, double to_radians) -> OGRErr"""
        return _osr.SpatialReference_SetAngularUnits(self, *args)


    def GetAngularUnits(self, *args):
        """GetAngularUnits(SpatialReference self) -> double"""
        return _osr.SpatialReference_GetAngularUnits(self, *args)


    def GetAngularUnitsName(self, *args):
        """GetAngularUnitsName(SpatialReference self) -> char const *"""
        return _osr.SpatialReference_GetAngularUnitsName(self, *args)


    def SetTargetLinearUnits(self, *args):
        """SetTargetLinearUnits(SpatialReference self, char const * target, char const * name, double to_meters) -> OGRErr"""
        return _osr.SpatialReference_SetTargetLinearUnits(self, *args)


    def SetLinearUnits(self, *args):
        """SetLinearUnits(SpatialReference self, char const * name, double to_meters) -> OGRErr"""
        return _osr.SpatialReference_SetLinearUnits(self, *args)


    def SetLinearUnitsAndUpdateParameters(self, *args):
        """SetLinearUnitsAndUpdateParameters(SpatialReference self, char const * name, double to_meters) -> OGRErr"""
        return _osr.SpatialReference_SetLinearUnitsAndUpdateParameters(self, *args)


    def GetTargetLinearUnits(self, *args):
        """GetTargetLinearUnits(SpatialReference self, char const * target_key) -> double"""
        return _osr.SpatialReference_GetTargetLinearUnits(self, *args)


    def GetLinearUnits(self, *args):
        """GetLinearUnits(SpatialReference self) -> double"""
        return _osr.SpatialReference_GetLinearUnits(self, *args)


    def GetLinearUnitsName(self, *args):
        """GetLinearUnitsName(SpatialReference self) -> char const *"""
        return _osr.SpatialReference_GetLinearUnitsName(self, *args)


    def GetAuthorityCode(self, *args):
        """GetAuthorityCode(SpatialReference self, char const * target_key) -> char const *"""
        return _osr.SpatialReference_GetAuthorityCode(self, *args)


    def GetAuthorityName(self, *args):
        """GetAuthorityName(SpatialReference self, char const * target_key) -> char const *"""
        return _osr.SpatialReference_GetAuthorityName(self, *args)


    def GetAxisName(self, *args):
        """GetAxisName(SpatialReference self, char const * target_key, int iAxis) -> char const *"""
        return _osr.SpatialReference_GetAxisName(self, *args)


    def GetAxisOrientation(self, *args):
        """GetAxisOrientation(SpatialReference self, char const * target_key, int iAxis) -> OGRAxisOrientation"""
        return _osr.SpatialReference_GetAxisOrientation(self, *args)


    def SetUTM(self, *args):
        """SetUTM(SpatialReference self, int zone, int north=1) -> OGRErr"""
        return _osr.SpatialReference_SetUTM(self, *args)


    def GetUTMZone(self, *args):
        """GetUTMZone(SpatialReference self) -> int"""
        return _osr.SpatialReference_GetUTMZone(self, *args)


    def SetStatePlane(self, *args):
        """SetStatePlane(SpatialReference self, int zone, int is_nad83=1, char const * unitsname, double units=0.0) -> OGRErr"""
        return _osr.SpatialReference_SetStatePlane(self, *args)


    def AutoIdentifyEPSG(self, *args):
        """AutoIdentifyEPSG(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_AutoIdentifyEPSG(self, *args)


    def SetProjection(self, *args):
        """SetProjection(SpatialReference self, char const * arg) -> OGRErr"""
        return _osr.SpatialReference_SetProjection(self, *args)


    def SetProjParm(self, *args):
        """SetProjParm(SpatialReference self, char const * name, double val) -> OGRErr"""
        return _osr.SpatialReference_SetProjParm(self, *args)


    def GetProjParm(self, *args):
        """GetProjParm(SpatialReference self, char const * name, double default_val=0.0) -> double"""
        return _osr.SpatialReference_GetProjParm(self, *args)


    def SetNormProjParm(self, *args):
        """SetNormProjParm(SpatialReference self, char const * name, double val) -> OGRErr"""
        return _osr.SpatialReference_SetNormProjParm(self, *args)


    def GetNormProjParm(self, *args):
        """GetNormProjParm(SpatialReference self, char const * name, double default_val=0.0) -> double"""
        return _osr.SpatialReference_GetNormProjParm(self, *args)


    def GetSemiMajor(self, *args):
        """GetSemiMajor(SpatialReference self) -> double"""
        return _osr.SpatialReference_GetSemiMajor(self, *args)


    def GetSemiMinor(self, *args):
        """GetSemiMinor(SpatialReference self) -> double"""
        return _osr.SpatialReference_GetSemiMinor(self, *args)


    def GetInvFlattening(self, *args):
        """GetInvFlattening(SpatialReference self) -> double"""
        return _osr.SpatialReference_GetInvFlattening(self, *args)


    def SetACEA(self, *args, **kwargs):
        """SetACEA(SpatialReference self, double stdp1, double stdp2, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetACEA(self, *args, **kwargs)


    def SetAE(self, *args, **kwargs):
        """SetAE(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetAE(self, *args, **kwargs)


    def SetBonne(self, *args, **kwargs):
        """SetBonne(SpatialReference self, double stdp, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetBonne(self, *args, **kwargs)


    def SetCEA(self, *args, **kwargs):
        """SetCEA(SpatialReference self, double stdp1, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetCEA(self, *args, **kwargs)


    def SetCS(self, *args, **kwargs):
        """SetCS(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetCS(self, *args, **kwargs)


    def SetEC(self, *args, **kwargs):
        """SetEC(SpatialReference self, double stdp1, double stdp2, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetEC(self, *args, **kwargs)


    def SetEckertIV(self, *args, **kwargs):
        """SetEckertIV(SpatialReference self, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetEckertIV(self, *args, **kwargs)


    def SetEckertVI(self, *args, **kwargs):
        """SetEckertVI(SpatialReference self, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetEckertVI(self, *args, **kwargs)


    def SetEquirectangular(self, *args, **kwargs):
        """SetEquirectangular(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetEquirectangular(self, *args, **kwargs)


    def SetEquirectangular2(self, *args, **kwargs):
        """SetEquirectangular2(SpatialReference self, double clat, double clong, double pseudostdparallellat, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetEquirectangular2(self, *args, **kwargs)


    def SetGaussSchreiberTMercator(self, *args, **kwargs):
        """SetGaussSchreiberTMercator(SpatialReference self, double clat, double clong, double sc, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetGaussSchreiberTMercator(self, *args, **kwargs)


    def SetGS(self, *args, **kwargs):
        """SetGS(SpatialReference self, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetGS(self, *args, **kwargs)


    def SetGH(self, *args, **kwargs):
        """SetGH(SpatialReference self, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetGH(self, *args, **kwargs)


    def SetIGH(self, *args):
        """SetIGH(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_SetIGH(self, *args)


    def SetGEOS(self, *args, **kwargs):
        """SetGEOS(SpatialReference self, double cm, double satelliteheight, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetGEOS(self, *args, **kwargs)


    def SetGnomonic(self, *args, **kwargs):
        """SetGnomonic(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetGnomonic(self, *args, **kwargs)


    def SetHOM(self, *args, **kwargs):
        """SetHOM(SpatialReference self, double clat, double clong, double azimuth, double recttoskew, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetHOM(self, *args, **kwargs)


    def SetHOM2PNO(self, *args, **kwargs):
        """SetHOM2PNO(SpatialReference self, double clat, double dfLat1, double dfLong1, double dfLat2, double dfLong2, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetHOM2PNO(self, *args, **kwargs)


    def SetKrovak(self, *args, **kwargs):
        """SetKrovak(SpatialReference self, double clat, double clong, double azimuth, double pseudostdparallellat, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetKrovak(self, *args, **kwargs)


    def SetLAEA(self, *args, **kwargs):
        """SetLAEA(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetLAEA(self, *args, **kwargs)


    def SetLCC(self, *args, **kwargs):
        """SetLCC(SpatialReference self, double stdp1, double stdp2, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetLCC(self, *args, **kwargs)


    def SetLCC1SP(self, *args, **kwargs):
        """SetLCC1SP(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetLCC1SP(self, *args, **kwargs)


    def SetLCCB(self, *args, **kwargs):
        """SetLCCB(SpatialReference self, double stdp1, double stdp2, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetLCCB(self, *args, **kwargs)


    def SetMC(self, *args, **kwargs):
        """SetMC(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetMC(self, *args, **kwargs)


    def SetMercator(self, *args, **kwargs):
        """SetMercator(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetMercator(self, *args, **kwargs)


    def SetMollweide(self, *args, **kwargs):
        """SetMollweide(SpatialReference self, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetMollweide(self, *args, **kwargs)


    def SetNZMG(self, *args, **kwargs):
        """SetNZMG(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetNZMG(self, *args, **kwargs)


    def SetOS(self, *args, **kwargs):
        """SetOS(SpatialReference self, double dfOriginLat, double dfCMeridian, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetOS(self, *args, **kwargs)


    def SetOrthographic(self, *args, **kwargs):
        """SetOrthographic(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetOrthographic(self, *args, **kwargs)


    def SetPolyconic(self, *args, **kwargs):
        """SetPolyconic(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetPolyconic(self, *args, **kwargs)


    def SetPS(self, *args, **kwargs):
        """SetPS(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetPS(self, *args, **kwargs)


    def SetRobinson(self, *args, **kwargs):
        """SetRobinson(SpatialReference self, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetRobinson(self, *args, **kwargs)


    def SetSinusoidal(self, *args, **kwargs):
        """SetSinusoidal(SpatialReference self, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetSinusoidal(self, *args, **kwargs)


    def SetStereographic(self, *args, **kwargs):
        """SetStereographic(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetStereographic(self, *args, **kwargs)


    def SetSOC(self, *args, **kwargs):
        """SetSOC(SpatialReference self, double latitudeoforigin, double cm, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetSOC(self, *args, **kwargs)


    def SetTM(self, *args, **kwargs):
        """SetTM(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetTM(self, *args, **kwargs)


    def SetTMVariant(self, *args, **kwargs):
        """SetTMVariant(SpatialReference self, char const * pszVariantName, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetTMVariant(self, *args, **kwargs)


    def SetTMG(self, *args, **kwargs):
        """SetTMG(SpatialReference self, double clat, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetTMG(self, *args, **kwargs)


    def SetTMSO(self, *args, **kwargs):
        """SetTMSO(SpatialReference self, double clat, double clong, double scale, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetTMSO(self, *args, **kwargs)


    def SetVDG(self, *args, **kwargs):
        """SetVDG(SpatialReference self, double clong, double fe, double fn) -> OGRErr"""
        return _osr.SpatialReference_SetVDG(self, *args, **kwargs)


    def SetWellKnownGeogCS(self, *args):
        """SetWellKnownGeogCS(SpatialReference self, char const * name) -> OGRErr"""
        return _osr.SpatialReference_SetWellKnownGeogCS(self, *args)


    def SetFromUserInput(self, *args):
        """SetFromUserInput(SpatialReference self, char const * name) -> OGRErr"""
        return _osr.SpatialReference_SetFromUserInput(self, *args)


    def CopyGeogCSFrom(self, *args):
        """CopyGeogCSFrom(SpatialReference self, SpatialReference rhs) -> OGRErr"""
        return _osr.SpatialReference_CopyGeogCSFrom(self, *args)


    def SetTOWGS84(self, *args):
        """SetTOWGS84(SpatialReference self, double p1, double p2, double p3, double p4=0.0, double p5=0.0, double p6=0.0, double p7=0.0) -> OGRErr"""
        return _osr.SpatialReference_SetTOWGS84(self, *args)


    def GetTOWGS84(self, *args):
        """GetTOWGS84(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_GetTOWGS84(self, *args)


    def SetLocalCS(self, *args):
        """SetLocalCS(SpatialReference self, char const * pszName) -> OGRErr"""
        return _osr.SpatialReference_SetLocalCS(self, *args)


    def SetGeogCS(self, *args):
        """SetGeogCS(SpatialReference self, char const * pszGeogName, char const * pszDatumName, char const * pszEllipsoidName, double dfSemiMajor, double dfInvFlattening, char const * pszPMName, double dfPMOffset=0.0, char const * pszUnits, double dfConvertToRadians=0.0174532925199433) -> OGRErr"""
        return _osr.SpatialReference_SetGeogCS(self, *args)


    def SetProjCS(self, *args):
        """SetProjCS(SpatialReference self, char const * name) -> OGRErr"""
        return _osr.SpatialReference_SetProjCS(self, *args)


    def SetGeocCS(self, *args):
        """SetGeocCS(SpatialReference self, char const * name) -> OGRErr"""
        return _osr.SpatialReference_SetGeocCS(self, *args)


    def SetVertCS(self, *args):
        """SetVertCS(SpatialReference self, char const * VertCSName, char const * VertDatumName, int VertDatumType=0) -> OGRErr"""
        return _osr.SpatialReference_SetVertCS(self, *args)


    def SetCompoundCS(self, *args):
        """SetCompoundCS(SpatialReference self, char const * name, SpatialReference horizcs, SpatialReference vertcs) -> OGRErr"""
        return _osr.SpatialReference_SetCompoundCS(self, *args)


    def ImportFromWkt(self, *args):
        """ImportFromWkt(SpatialReference self, char ** ppszInput) -> OGRErr"""
        return _osr.SpatialReference_ImportFromWkt(self, *args)


    def ImportFromProj4(self, *args):
        """ImportFromProj4(SpatialReference self, char * ppszInput) -> OGRErr"""
        return _osr.SpatialReference_ImportFromProj4(self, *args)


    def ImportFromUrl(self, *args):
        """ImportFromUrl(SpatialReference self, char * url) -> OGRErr"""
        return _osr.SpatialReference_ImportFromUrl(self, *args)


    def ImportFromESRI(self, *args):
        """ImportFromESRI(SpatialReference self, char ** ppszInput) -> OGRErr"""
        return _osr.SpatialReference_ImportFromESRI(self, *args)


    def ImportFromEPSG(self, *args):
        """ImportFromEPSG(SpatialReference self, int arg) -> OGRErr"""
        return _osr.SpatialReference_ImportFromEPSG(self, *args)


    def ImportFromEPSGA(self, *args):
        """ImportFromEPSGA(SpatialReference self, int arg) -> OGRErr"""
        return _osr.SpatialReference_ImportFromEPSGA(self, *args)


    def ImportFromPCI(self, *args):
        """ImportFromPCI(SpatialReference self, char const * proj, char const * units, double [17] argin=0) -> OGRErr"""
        return _osr.SpatialReference_ImportFromPCI(self, *args)


    def ImportFromUSGS(self, *args):
        """ImportFromUSGS(SpatialReference self, long proj_code, long zone=0, double [15] argin=0, long datum_code=0) -> OGRErr"""
        return _osr.SpatialReference_ImportFromUSGS(self, *args)


    def ImportFromXML(self, *args):
        """ImportFromXML(SpatialReference self, char const * xmlString) -> OGRErr"""
        return _osr.SpatialReference_ImportFromXML(self, *args)


    def ImportFromERM(self, *args):
        """ImportFromERM(SpatialReference self, char const * proj, char const * datum, char const * units) -> OGRErr"""
        return _osr.SpatialReference_ImportFromERM(self, *args)


    def ImportFromMICoordSys(self, *args):
        """ImportFromMICoordSys(SpatialReference self, char const * pszCoordSys) -> OGRErr"""
        return _osr.SpatialReference_ImportFromMICoordSys(self, *args)


    def ImportFromOzi(self, *args):
        """ImportFromOzi(SpatialReference self, char const *const * papszLines) -> OGRErr"""
        return _osr.SpatialReference_ImportFromOzi(self, *args)


    def ExportToWkt(self, *args):
        """ExportToWkt(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_ExportToWkt(self, *args)


    def ExportToPrettyWkt(self, *args):
        """ExportToPrettyWkt(SpatialReference self, int simplify=0) -> OGRErr"""
        return _osr.SpatialReference_ExportToPrettyWkt(self, *args)


    def ExportToProj4(self, *args):
        """ExportToProj4(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_ExportToProj4(self, *args)


    def ExportToPCI(self, *args):
        """ExportToPCI(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_ExportToPCI(self, *args)


    def ExportToUSGS(self, *args):
        """ExportToUSGS(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_ExportToUSGS(self, *args)


    def ExportToXML(self, *args):
        """ExportToXML(SpatialReference self, char const * dialect) -> OGRErr"""
        return _osr.SpatialReference_ExportToXML(self, *args)


    def ExportToMICoordSys(self, *args):
        """ExportToMICoordSys(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_ExportToMICoordSys(self, *args)


    def CloneGeogCS(self, *args):
        """CloneGeogCS(SpatialReference self) -> SpatialReference"""
        return _osr.SpatialReference_CloneGeogCS(self, *args)


    def Clone(self, *args):
        """Clone(SpatialReference self) -> SpatialReference"""
        return _osr.SpatialReference_Clone(self, *args)


    def Validate(self, *args):
        """Validate(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_Validate(self, *args)


    def StripCTParms(self, *args):
        """StripCTParms(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_StripCTParms(self, *args)


    def FixupOrdering(self, *args):
        """FixupOrdering(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_FixupOrdering(self, *args)


    def Fixup(self, *args):
        """Fixup(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_Fixup(self, *args)


    def MorphToESRI(self, *args):
        """MorphToESRI(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_MorphToESRI(self, *args)


    def MorphFromESRI(self, *args):
        """MorphFromESRI(SpatialReference self) -> OGRErr"""
        return _osr.SpatialReference_MorphFromESRI(self, *args)

SpatialReference_swigregister = _osr.SpatialReference_swigregister
SpatialReference_swigregister(SpatialReference)
GetProjectionMethods = _osr.GetProjectionMethods

class CoordinateTransformation(_object):
    """Proxy of C++ OSRCoordinateTransformationShadow class."""

    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, CoordinateTransformation, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, CoordinateTransformation, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        """__init__(OSRCoordinateTransformationShadow self, SpatialReference src, SpatialReference dst) -> CoordinateTransformation"""
        this = _osr.new_CoordinateTransformation(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _osr.delete_CoordinateTransformation
    __del__ = lambda self: None

    def TransformPoint(self, *args):
        """
        TransformPoint(CoordinateTransformation self, double [3] inout)
        TransformPoint(CoordinateTransformation self, double x, double y, double z=0.0)
        """
        return _osr.CoordinateTransformation_TransformPoint(self, *args)


    def TransformPoints(self, *args):
        """TransformPoints(CoordinateTransformation self, int nCount)"""
        return _osr.CoordinateTransformation_TransformPoints(self, *args)

CoordinateTransformation_swigregister = _osr.CoordinateTransformation_swigregister
CoordinateTransformation_swigregister(CoordinateTransformation)


def CreateCoordinateTransformation(*args):
    """CreateCoordinateTransformation(SpatialReference src, SpatialReference dst) -> CoordinateTransformation"""
    return _osr.CreateCoordinateTransformation(*args)
# This file is compatible with both classic and new-style classes.





#  tests for gdal-2.2.2-py27h58389d3_1 (this is a generated file);
print('===== testing package: gdal-2.2.2-py27h58389d3_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from osgeo import gdal
from osgeo import ogr
from osgeo import osr

# Avoid the regressing from https://github.com/conda-forge/gdal-feedstock/pull/129
# See https://github.com/conda-forge/gdal-feedstock/issues/131
from osgeo.gdal_array import *

driver = gdal.GetDriverByName("netCDF")
assert driver is not None, "netcdf not linked in correctly"

driver = gdal.GetDriverByName("HDF4")
assert driver is not None, "hdf4 not linked in correctly"

driver = gdal.GetDriverByName("HDF5")
assert driver is not None, "hdf5 not linked in correctly"

driver = gdal.GetDriverByName("GTiff")
assert driver is not None, "tiff not linked in correctly"

driver = gdal.GetDriverByName("PNG")
assert driver is not None, "png not linked in correctly"

driver = gdal.GetDriverByName("JPEG")
assert driver is not None, "jpeg not linked in correctly"

driver = gdal.GetDriverByName("GPKG")
assert driver is not None

# only available when libkea successfully linked in.
driver = gdal.GetDriverByName("KEA")
assert driver is not None, "kealib not linked in correctly"

# only available when xerces-c++ successfully linked in.
driver = ogr.GetDriverByName("GML")
assert driver is not None, "xerces-c not linked in correctly"

# only available when openjpeg successfully linked in.
driver = gdal.GetDriverByName("JP2OpenJPEG")
assert driver is not None, "openjpeg not linked in correctly"

# only available when curl successfully linked in.
driver = gdal.GetDriverByName("WCS")
assert driver is not None, "curl not linked in correctly"

# only available when freexl successfully linked in.
driver = ogr.GetDriverByName("XLS")
assert driver is not None, "freexl not linked in correctly"

# only available when expat successfully linked in.
driver = ogr.GetDriverByName("KML")
assert driver is not None, "kml not linked in correctly"

# only available when SQLite successfully linked in.
driver = ogr.GetDriverByName("SQLite")
assert driver is not None, "sqlite not linked in correctly"

# only available when PostgreSQL successfully linked in.
driver = ogr.GetDriverByName("PostgreSQL")
assert driver is not None, "postgres not linked in correctly"

def has_geos():
    pnt1 = ogr.CreateGeometryFromWkt( 'POINT(10 20)' )
    pnt2 = ogr.CreateGeometryFromWkt( 'POINT(30 20)' )
    ogrex = ogr.GetUseExceptions()
    ogr.DontUseExceptions()
    hasgeos = pnt1.Union( pnt2 ) is not None
    if ogrex:
        ogr.UseExceptions()
    return hasgeos

assert has_geos(), 'GEOS not available within GDAL'

def has_proj():
    sr1 = osr.SpatialReference()
    sr1.ImportFromEPSG(4326) # lat, lon.
    sr2 = osr.SpatialReference()
    sr2.ImportFromEPSG(28355) # GDA94/MGA zone 55.
    osrex = osr.GetUseExceptions()
    osr.UseExceptions()
    hasproj = True
    # Use exceptions to determine if we have proj and epsg files
    # otherwise we can't reliably determine if it has failed.
    try:
        trans = osr.CoordinateTransformation(sr1, sr2)
    except RuntimeError:
        hasproj = False
    return hasproj

assert has_proj(), 'PROJ not available within GDAL'

# Test https://github.com/swig/swig/issues/567
def make_geom():
    geom = ogr.Geometry(ogr.wkbPoint)
    geom.AddPoint_2D(0, 0)
    return geom

def gen_list(N):
    for i in range(N):
        geom = make_geom()
        yield i

N = 10
assert list(gen_list(N)) == list(range(N))

# This module does some additional tests.
import extra_tests
#  --- run_test.py (end) ---

print('===== gdal-2.2.2-py27h58389d3_1 OK =====');
print("import: 'osr'")
import osr

print("import: 'gdal'")
import gdal

print("import: 'gdalconst'")
import gdalconst

print("import: 'osgeo'")
import osgeo

print("import: 'osgeo.ogr'")
import osgeo.ogr

print("import: 'osgeo.gdal'")
import osgeo.gdal

print("import: 'osgeo._gdal'")
import osgeo._gdal

print("import: 'osgeo._gdalconst'")
import osgeo._gdalconst

print("import: 'osgeo._ogr'")
import osgeo._ogr

print("import: 'osgeo._osr'")
import osgeo._osr




#!C:\ci\gdal_1511390832795\_h_env\python.exe
# -*- coding: utf-8 -*-
###############################################################################
# $Id: gdal_edit.py 37709 2017-03-14 14:52:15Z rouault $
#
#  Project:  GDAL samples
#  Purpose:  Edit in place various information of an existing GDAL dataset
#  Author:   Even Rouault <even dot rouault at mines dash paris dot org>
#
###############################################################################
#  Copyright (c) 2011-2013, Even Rouault <even dot rouault at mines-paris dot org>
#
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
###############################################################################

import sys

from osgeo import gdal
from osgeo import osr

def Usage():
    print('Usage: gdal_edit [--help-general] [-ro] [-a_srs srs_def] [-a_ullr ulx uly lrx lry]')
    print('                 [-tr xres yres] [-unsetgt] [-a_nodata value] [-unsetnodata]')
    print('                 [-offset value] [-scale value]')
    print('                 [-unsetstats] [-stats] [-approx_stats]')
    print('                 [-gcp pixel line easting northing [elevation]]*')
    print('                 [-unsetmd] [-oo NAME=VALUE]* [-mo "META-TAG=VALUE"]*  datasetname')
    print('')
    print('Edit in place various information of an existing GDAL dataset.')
    return -1


def ArgIsNumeric(s):
    i = 0

    while i < len(s):
        if ( s[i] < '0' or s[i] > '9') and s[i] != '.' and s[i] != 'e' and s[i] != '+' and s[i] != '-':
            return False
        i = i + 1

    return True

def gdal_edit(argv):

    argv = gdal.GeneralCmdLineProcessor( argv )
    if argv is None:
        return -1

    datasetname = None
    srs = None
    ulx = None
    uly = None
    lrx = None
    lry = None
    nodata = None
    unsetnodata = False
    xres = None
    yres = None
    unsetgt = False
    unsetstats = False
    stats = False
    approx_stats = False
    unsetmd = False
    ro = False
    molist = []
    gcp_list = []
    open_options = []
    offset = None
    scale = None

    i = 1
    argc = len(argv)
    while i < argc:
        if argv[i] == '-ro':
            ro = True
        elif argv[i] == '-a_srs' and i < len(argv)-1:
            srs = argv[i+1]
            i = i + 1
        elif argv[i] == '-a_ullr' and i < len(argv)-4:
            ulx = float(argv[i+1])
            i = i + 1
            uly = float(argv[i+1])
            i = i + 1
            lrx = float(argv[i+1])
            i = i + 1
            lry = float(argv[i+1])
            i = i + 1
        elif argv[i] == '-tr' and i < len(argv)-2:
            xres = float(argv[i+1])
            i = i + 1
            yres = float(argv[i+1])
            i = i + 1
        elif argv[i] == '-a_nodata' and i < len(argv)-1:
            nodata = float(argv[i+1])
            i = i + 1
        elif argv[i] == '-scale' and i < len(argv)-1:
            scale = float(argv[i+1])
            i = i + 1
        elif argv[i] == '-offset' and i < len(argv)-1:
            offset = float(argv[i+1])
            i = i + 1
        elif argv[i] == '-mo' and i < len(argv)-1:
            molist.append(argv[i+1])
            i = i + 1
        elif argv[i] == '-gcp' and i + 4 < len(argv):
            pixel = float(argv[i+1])
            i = i + 1
            line = float(argv[i+1])
            i = i + 1
            x = float(argv[i+1])
            i = i + 1
            y = float(argv[i+1])
            i = i + 1
            if i + 1 < len(argv) and ArgIsNumeric(argv[i+1]):
                z = float(argv[i+1])
                i = i + 1
            else:
                z = 0
            gcp = gdal.GCP(x,y,z,pixel,line)
            gcp_list.append(gcp)
        elif argv[i] == '-unsetgt' :
            unsetgt = True
        elif argv[i] == '-unsetstats':
            unsetstats = True
        elif argv[i] == '-approx_stats':
            stats = True
            approx_stats = True
        elif argv[i] == '-stats':
            stats = True
        elif argv[i] == '-unsetmd':
            unsetmd = True
        elif argv[i] == '-unsetnodata':
            unsetnodata = True
        elif argv[i] == '-oo' and i < len(argv)-1:
            open_options.append(argv[i+1])
            i = i + 1
        elif argv[i][0] == '-':
            sys.stderr.write('Unrecognized option : %s\n' % argv[i])
            return Usage()
        elif datasetname is None:
            datasetname = argv[i]
        else:
            sys.stderr.write('Unexpected option : %s\n' % argv[i])
            return Usage()

        i = i + 1

    if datasetname is None:
        return Usage()

    if (srs is None and lry is None and yres is None and not unsetgt
            and not unsetstats and not stats and nodata is None
            and len(molist) == 0 and not unsetmd and len(gcp_list) == 0
            and not unsetnodata
            and scale is None and offset is None):
        print('No option specified')
        print('')
        return Usage()

    exclusive_option = 0
    if lry is not None:
        exclusive_option = exclusive_option + 1
    if yres is not None:
        exclusive_option = exclusive_option + 1
    if unsetgt:
        exclusive_option = exclusive_option + 1
    if exclusive_option > 1:
        print('-a_ullr, -tr and -unsetgt options are exclusive.')
        print('')
        return Usage()

    if unsetstats and stats:
        print('-unsetstats and either -stats or -approx_stats options are exclusive.')
        print('')
        return Usage()

    if unsetnodata and nodata:
        print('-unsetnodata and -nodata options are exclusive.')
        print('')
        return Usage()

    if open_options is not None:
        if ro:
            ds = gdal.OpenEx(datasetname, gdal.OF_RASTER, open_options = open_options)
        else:
            ds = gdal.OpenEx(datasetname, gdal.OF_RASTER | gdal.OF_UPDATE, open_options = open_options)
    # GDAL 1.X compat
    elif ro:
        ds = gdal.Open(datasetname)
    else:
        ds = gdal.Open(datasetname, gdal.GA_Update)
    if ds is None:
        return -1

    wkt = None
    if srs == '' or srs == 'None':
        ds.SetProjection('')
    elif srs is not None:
        sr = osr.SpatialReference()
        if sr.SetFromUserInput(srs) != 0:
            print('Failed to process SRS definition: %s' % srs)
            return -1
        wkt = sr.ExportToWkt()
        if len(gcp_list) == 0:
            ds.SetProjection(wkt)

    if lry is not None:
        gt = [ ulx, (lrx - ulx) / ds.RasterXSize, 0,
               uly, 0, (lry - uly) / ds.RasterYSize ]
        ds.SetGeoTransform(gt)

    if yres is not None:
        gt = ds.GetGeoTransform()
        # Doh ! why is gt a tuple and not an array...
        gt = [ gt[j] for j in range(6) ]
        gt[1] = xres
        gt[5] = yres
        ds.SetGeoTransform(gt)

    if unsetgt:
        ds.SetGeoTransform([0,1,0,0,0,1])

    if len(gcp_list) > 0:
        if wkt is None:
            wkt = ds.GetGCPProjection()
        if wkt is None:
            wkt = ''
        ds.SetGCPs(gcp_list, wkt)

    if nodata is not None:
        for i in range(ds.RasterCount):
            ds.GetRasterBand(i+1).SetNoDataValue(nodata)
    elif unsetnodata:
        for i in range(ds.RasterCount):
            ds.GetRasterBand(i+1).DeleteNoDataValue()

    if scale is not None:
        for i in range(ds.RasterCount):
            ds.GetRasterBand(i+1).SetScale(scale)

    if offset is not None:
       for i in range(ds.RasterCount):
           ds.GetRasterBand(i+1).SetOffset(offset)
 
    if unsetstats:
        for i in range(ds.RasterCount):
            band = ds.GetRasterBand(i+1)
            for key in band.GetMetadata().keys():
                if key.startswith('STATISTICS_'):
                    band.SetMetadataItem(key, None)

    if stats:
        for i in range(ds.RasterCount):
            ds.GetRasterBand(i+1).ComputeStatistics(approx_stats)

    if len(molist) != 0:
        if unsetmd:
            md = {}
        else:
            md = ds.GetMetadata()
        for moitem in molist:
            equal_pos = moitem.find('=')
            if equal_pos > 0:
                md[moitem[0:equal_pos]] = moitem[equal_pos+1:]
        ds.SetMetadata(md)
    elif unsetmd:
        ds.SetMetadata({})

    ds = band = None

    return 0

def main():
    return gdal_edit(sys.argv)

if __name__ == '__main__':
    sys.exit(gdal_edit(sys.argv))



#!C:\ci\gdal_1511390832795\_h_env\python.exe
# -*- coding: utf-8 -*-
#******************************************************************************
#
#  Project:  GDAL
#  Purpose:  Compare two files for differences and report.
#  Author:   Frank Warmerdam, warmerdam@pobox.com
#
#******************************************************************************
#  Copyright (c) 2012, Frank Warmerdam <warmerdam@pobox.com>
#
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#******************************************************************************

import os
import sys
import filecmp

from osgeo import gdal
from osgeo import osr

#######################################################
def compare_metadata(golden_md, new_md, id, options=[]):
  if golden_md is None and new_md is None:
    return 0

  found_diff = 0

  if len(list(golden_md.keys())) != len(list(new_md.keys())):
    print('Difference in %s metadata key count' % id)
    print('  Golden Keys: ' + str(list(golden_md.keys())))
    print('  New Keys: ' + str(list(new_md.keys())))
    found_diff += 1

  for key in list(golden_md.keys()):
    if key not in new_md:
      print('New %s metadata lacks key \"%s\"' % (id, key))
      found_diff += 1
    elif new_md[key] != golden_md[key]:
      print('Metadata value difference for key "' + key + '"')
      print('  Golden: "' + golden_md[key] + '"')
      print('  New:    "' + new_md[key] + '"')
      found_diff += 1

  return found_diff


#######################################################
# Review and report on the actual image pixels that differ.
def compare_image_pixels(golden_band, new_band, id, options=[]):
  diff_count = 0
  max_diff = 0

  for line in range(golden_band.YSize):
    golden_line = golden_band.ReadAsArray(0, line, golden_band.XSize, 1)[0]
    new_line = new_band.ReadAsArray(0, line, golden_band.XSize, 1)[0]
    diff_line = golden_line.astype(float) - new_line.astype(float)
    max_diff = max(max_diff,abs(diff_line).max())
    diff_count += len(diff_line.nonzero()[0])

  print('  Pixels Differing: ' + str(diff_count))
  print('  Maximum Pixel Difference: ' + str(max_diff))

#######################################################
def compare_band(golden_band, new_band, id, options=[]):
  found_diff = 0

  if golden_band.DataType != new_band.DataType:
    print('Band %s pixel types differ.' % id)
    print('  Golden: ' + gdal.GetDataTypeName(golden_band.DataType))
    print('  New:    ' + gdal.GetDataTypeName(new_band.DataType))
    found_diff += 1

  if golden_band.GetNoDataValue() != new_band.GetNoDataValue():
    print('Band %s nodata values differ.' % id)
    print('  Golden: ' + str(golden_band.GetNoDataValue()))
    print('  New:    ' + str(new_band.GetNoDataValue()))
    found_diff += 1

  if golden_band.GetColorInterpretation() != new_band.GetColorInterpretation():
    print('Band %s color interpretation values differ.' % id)
    print('  Golden: ' +  gdal.GetColorInterpretationName(golden_band.GetColorInterpretation()))
    print('  New:    ' + gdal.GetColorInterpretationName(new_band.GetColorInterpretation()))
    found_diff += 1

  if golden_band.Checksum() != new_band.Checksum():
    print('Band %s checksum difference:' % id)
    print('  Golden: ' + str(golden_band.Checksum()))
    print('  New:    ' + str(new_band.Checksum()))
    found_diff += 1
    compare_image_pixels(golden_band,new_band, id, options)

  # Check overviews
  if golden_band.GetOverviewCount() != new_band.GetOverviewCount():
    print('Band %s overview count difference:' % id)
    print('  Golden: ' + str(golden_band.GetOverviewCount()))
    print('  New:    ' + str(new_band.GetOverviewCount()))
    found_diff += 1
  else:
    for i in range(golden_band.GetOverviewCount()):
      found_diff += compare_band(golden_band.GetOverview(i),
                   new_band.GetOverview(i),
                   id + ' overview ' + str(i),
                   options)

  # Metadata
  if 'SKIP_METADATA' not in options:
      found_diff += compare_metadata(golden_band.GetMetadata(),
                                     new_band.GetMetadata(),
                                     'Band ' + id, options)

  # TODO: Color Table, gain/bias, units, blocksize, mask, min/max

  return found_diff

#######################################################
def compare_srs(golden_wkt, new_wkt):
  if golden_wkt == new_wkt:
    return 0

  print('Difference in SRS!')

  golden_srs = osr.SpatialReference(golden_wkt)
  new_srs = osr.SpatialReference(new_wkt)

  if golden_srs.IsSame(new_srs):
    print('  * IsSame() reports them as equivalent.')
  else:
    print('  * IsSame() reports them as different.')

  print('  Golden:')
  print('  ' + golden_srs.ExportToPrettyWkt())
  print('  New:')
  print('  ' + new_srs.ExportToPrettyWkt())

  return 1

#######################################################
def compare_db(golden_db, new_db, options=[]):
  found_diff = 0

  # SRS
  if 'SKIP_SRS' not in options:
      found_diff += compare_srs(golden_db.GetProjection(),
                                new_db.GetProjection())

  # GeoTransform
  if 'SKIP_GEOTRANSFORM' not in options:
      golden_gt = golden_db.GetGeoTransform()
      new_gt = new_db.GetGeoTransform()
      if golden_gt != new_gt:
          print('GeoTransforms Differ:')
          print('  Golden: ' + str(golden_gt))
          print('  New:    ' + str(new_gt))
          found_diff += 1

  # Metadata
  if 'SKIP_METADATA' not in options:
      found_diff += compare_metadata(golden_db.GetMetadata(),
                                     new_db.GetMetadata(),
                                     'Dataset', options)

  # Bands
  if golden_db.RasterCount != new_db.RasterCount:
    print('Band count mismatch (golden=%d, new=%d)' \
        % (golden_db.RasterCount, new_db.RasterCount))
    found_diff += 1

  # Dimensions
  for i in range(golden_db.RasterCount):
      gSzX = golden_db.GetRasterBand(i+1).XSize
      nSzX = new_db.GetRasterBand(i+1).XSize
      gSzY = golden_db.GetRasterBand(i+1).YSize
      nSzY = new_db.GetRasterBand(i+1).YSize

      if gSzX != nSzX or gSzY != nSzY:
          print('Band size mismatch (band=%d golden=[%d,%d], new=[%d,%d])' %
                (i, gSzX, gSzY, nSzX, nSzY))
          found_diff += 1

  # If so-far-so-good, then compare pixels
  if found_diff == 0:
    for i in range(golden_db.RasterCount):
      found_diff += compare_band(golden_db.GetRasterBand(i+1),
                                 new_db.GetRasterBand(i+1),
                                 str(i+1),
                                 options)

  return found_diff

#######################################################
def compare_sds(golden_db, new_db, options=[]):
  found_diff = 0

  golden_sds = golden_db.GetMetadata('SUBDATASETS')
  new_sds = new_db.GetMetadata('SUBDATASETS')

  count = len(list(golden_sds.keys())) / 2
  for i in range(count):
    key = 'SUBDATASET_%d_NAME' % (i+1)

    sub_golden_db = gdal.Open(golden_sds[key])
    sub_new_db = gdal.Open(new_sds[key])

    sds_diff = compare_db(sub_golden_db, sub_new_db, options)
    found_diff += sds_diff
    if sds_diff > 0:
      print('%d differences found between:\n  %s\n  %s' \
            % (sds_diff, golden_sds[key],new_sds[key]))

  return found_diff

#######################################################
def Usage():
  print('Usage: gdalcompare.py [-sds] <golden_file> <new_file>')
  sys.exit(1)

#######################################################
#
# Mainline
#

if __name__ == '__main__':

  # Default GDAL argument parsing.
  argv = gdal.GeneralCmdLineProcessor( sys.argv )
  if argv is None:
    sys.exit( 0 )

  if len(argv) == 1:
    Usage()

  # Script argument parsing.
  golden_file = None
  new_file = None
  check_sds = 0

  i = 1
  while  i < len(argv):

    if argv[i] == '-sds':
      check_sds = 1

    elif golden_file is None:
      golden_file = argv[i]

    elif new_file is None:
      new_file = argv[i]

    else:
      print('Urecognised argument: ' + argv[i])
      Usage()

    i = i + 1
    # next argument

  #### Compare Files ####

  found_diff = 0

  # compare raw binary files.
  try:
    os.stat(golden_file)

    if not filecmp.cmp(golden_file,new_file):
      print('Files differ at the binary level.')
      found_diff += 1
  except:
    print('Skipped binary file comparison, golden file not in filesystem.')

  # compare as GDAL Datasets.
  golden_db = gdal.Open(golden_file)
  new_db = gdal.Open(new_file)
  found_diff += compare_db(golden_db, new_db)

  if check_sds:
    found_diff += compare_sds(golden_db, new_db)

  print('Differences Found: ' + str(found_diff))

  sys.exit(found_diff)



#!C:\ci\gdal_1511390832795\_h_env\python.exe
#******************************************************************************
#  $Id: gcps2vec.py 33790 2016-03-26 12:42:12Z goatbar $
#
#  Project:  GDAL
#  Purpose:  Convert GCPs to a point layer.
#  Author:   Frank Warmerdam, warmerdam@pobox.com
#
#******************************************************************************
#  Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
#
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#******************************************************************************

import sys

from osgeo import gdal
from osgeo import ogr
from osgeo import osr


def Usage():
    print('Usage: gcps2vec.py [-of <ogr_drivername>] [-p] <raster_file> <vector_file>')
    sys.exit(1)

# =============================================================================
# 	Mainline
# =============================================================================

out_format = 'GML'
in_file = None
out_file = None
pixel_out = 0

gdal.AllRegister()
argv = gdal.GeneralCmdLineProcessor( sys.argv )
if argv is None:
    sys.exit( 0 )

# Parse command line arguments.
i = 1
while i < len(argv):
    arg = argv[i]

    if arg == '-of':
        i = i + 1
        out_format = argv[i]

    elif arg == '-p':
        pixel_out = 1

    elif in_file is None:
        in_file = argv[i]

    elif out_file is None:
        out_file = argv[i]

    else:
        Usage()

    i = i + 1

if out_file is None:
    Usage()

# ----------------------------------------------------------------------------
# Open input file, and fetch GCPs.
# ----------------------------------------------------------------------------
ds = gdal.Open( in_file )
if ds is None:
    print('Unable to open %s' % in_file)
    sys.exit(1)

gcp_srs = ds.GetGCPProjection()
gcps = ds.GetGCPs()

ds = None

if gcps is None or len(gcps) == 0:
    print('No GCPs on file %s!' % in_file)
    sys.exit(1)

# ----------------------------------------------------------------------------
# Create output file, and layer.
# ----------------------------------------------------------------------------

drv = ogr.GetDriverByName( out_format )
if drv is None:
    print('No driver named %s available.' % out_format)
    sys.exit(1)

ds = drv.CreateDataSource( out_file )

if pixel_out == 0 and gcp_srs != "":
    srs = osr.SpatialReference()
    srs.ImportFromWkt(gcp_srs)
else:
    srs = None

if pixel_out == 0:
    geom_type = ogr.wkbPoint25D
else:
    geom_type = ogr.wkbPoint

layer = ds.CreateLayer( 'gcps', srs, geom_type = geom_type )

if pixel_out == 0:
    fd = ogr.FieldDefn( 'Pixel', ogr.OFTReal )
    layer.CreateField( fd )

    fd = ogr.FieldDefn( 'Line', ogr.OFTReal )
    layer.CreateField( fd )
else:
    fd = ogr.FieldDefn( 'X', ogr.OFTReal )
    layer.CreateField( fd )

    fd = ogr.FieldDefn( 'Y', ogr.OFTReal )
    layer.CreateField( fd )

    fd = ogr.FieldDefn( 'Z', ogr.OFTReal )
    layer.CreateField( fd )

fd = ogr.FieldDefn( 'Id', ogr.OFTString )
layer.CreateField( fd )

fd = ogr.FieldDefn( 'Info', ogr.OFTString )
layer.CreateField( fd )

# ----------------------------------------------------------------------------
# Write GCPs.
# ----------------------------------------------------------------------------

for gcp in gcps:

    feat = ogr.Feature( layer.GetLayerDefn() )

    if pixel_out == 0:
        geom = ogr.Geometry( geom_type )
        feat.SetField( 'Pixel', gcp.GCPPixel )
        feat.SetField( 'Line',  gcp.GCPLine )
        geom.SetPoint( 0, gcp.GCPX, gcp.GCPY, gcp.GCPZ )
    else:
        geom = ogr.Geometry( geom_type )
        feat.SetField( 'X', gcp.GCPX )
        feat.SetField( 'Y',  gcp.GCPY )
        feat.SetField( 'Z',  gcp.GCPZ )
        geom.SetPoint( 0, gcp.GCPPixel, gcp.GCPLine )

    feat.SetField( 'Id',    gcp.Id )
    feat.SetField( 'Info',  gcp.Info )

    feat.SetGeometryDirectly( geom )
    layer.CreateFeature( feat )

feat = None
ds.Destroy()
